/*
 * DialogDemo.java
 *
 * Created on 2001/04/22, 6:45
 */

import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;

import com.skyarts.midp.ui.Dialog;
import com.skyarts.midp.ui.DialogListener;
/**
 *
 * @author  SkyArts.com - Hideki Yonekawa
 * @version
 */
public class DialogDemo extends MIDlet implements DialogListener, CommandListener {

	private Display				display;

	private Dialog				dialog;

	//Menu list
	private List				menuList		= new List("A dialog is chosen.", Choice.IMPLICIT);

	//Sub menu list
	private List				subMenuList		= new List("A button-set is chosen.", Choice.IMPLICIT);

	private Command				backCmd			= new Command("Back", Command.SCREEN, 5);

	private Command				exitCmd			= new Command("Exit", Command.SCREEN, 5);

	public DialogDemo() {

		display = Display.getDisplay(this);

		menuList.append("Info dialog", null);
		menuList.append("Confirm dialog", null);
		menuList.append("Error dialog", null);
		menuList.append("Warning dialog", null);
		menuList.addCommand(exitCmd);
		menuList.setCommandListener(this);

		subMenuList.append("Yes, No, Cancel", null);
		subMenuList.append("Yes, No", null);
		subMenuList.append("Cancel", null);
		subMenuList.append("OK", null);
		subMenuList.addCommand(backCmd);
		subMenuList.setCommandListener(this);


		//The instance of a dialog is generated.
		dialog = new Dialog();

		//The title text of a dialog is set.
		dialog.setTitle("It's a SkyArts.com");

		//The color of a dialog is set.
		dialog.setDialogColor(0x00FF0000);

		//The text of a dialog is set (a new line is compulsorily started by attaching \n).
//		dialog.setText("SkyArts-Dialog is convenient!\nSkyArts-Dialog is convenient!");
		dialog.setText("Dialog is convenient!");

		//Language is set for the button of a dialog (a default is English).
//		dialog.setButtonLanguage(Dialog.LANG_EN);
//		dialog.setButtonLanguage(Dialog.LANG_JP);

		//DialogListener is set to a dialog.
		dialog.setDialogListener(this);
	}

	public void startApp() {
		//A menu is displayed.
		display.setCurrent(menuList);
	}

	public void pauseApp() {
	}

	public void destroyApp(boolean unconditional) {
	}

	/**
	 * The method called when the button of a dialog is pushed.
	 * @param   target		 Dialog component which the event generated.
	 * @param   buttonID	 ID of the pushed button. Dialog.BUTTON_YES, Dialog.BUTTON_NO, Dialog.BUTTON_CANCEL, or Dialog.BUTTON_OK.
	 */
	public void dialogEvent(Object target, int buttonID) {

		switch(buttonID) {
			case Dialog.BUTTON_YES:
				System.out.println("BUTTON_YES");
			break;

			case Dialog.BUTTON_NO:
				System.out.println("BUTTON_NO");
			break;
			
			case Dialog.BUTTON_CANCEL:
				System.out.println("BUTTON_CANCEL");
			break;
			
			case Dialog.BUTTON_OK:
				System.out.println("BUTTON_OK");
			break;
		}

		display.setCurrent(subMenuList);
	}

	public void commandAction(Command c, Displayable d) {
		if(d == menuList) {
			if(c == List.SELECT_COMMAND) {
				setDialogType(menuList.getSelectedIndex());
				display.setCurrent(subMenuList);
			}else if(c == exitCmd) {
				destroyApp(false);
				notifyDestroyed();
			}
		}else if(d == subMenuList) {
			if(c == List.SELECT_COMMAND) {
				setButtonSet(subMenuList.getSelectedIndex());
				display.setCurrent(dialog);
			}else if(c == backCmd) {
				display.setCurrent(menuList);
			}
		}
	}

	private void setDialogType(int type) {
		switch(type) {
			case 0:
				dialog.setType(Dialog.INFO);
			break;

			case 1:
				dialog.setType(Dialog.CONFIRM);
			break;
			
			case 2:
				dialog.setType(Dialog.ERROR);
			break;
			
			case 3:
				dialog.setType(Dialog.WRNING);
			break;
		}
	}

	private void setButtonSet(int buttonSet) {
		switch(buttonSet) {
			case 0:
				dialog.setButtonSet(Dialog.YES_NO_CANCEL_BUTTONSET);
			break;

			case 1:
				dialog.setButtonSet(Dialog.YES_NO_BUTTONSET);
			break;
			
			case 2:
				dialog.setButtonSet(Dialog.CANCEL_BUTTONSET);
			break;
			
			case 3:
				dialog.setButtonSet(Dialog.OK_BUTTONSET);
			break;
		}
	}
}
